meta_package_manager.tests package — Meta Package Manager 2.3.0 documentation

# meta_package_manager.tests package

## Submodules

## meta_package_manager.tests.case module

class `meta_package_manager.tests.case.` `CLITestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Utilities and helpers to easely write unit-tests.

  `invoke`(*args)

    Executes Click’s CLI, print output and return results.

  `print_cli_output`(cmd, output)

    Simulate CLI output.

    Used to print debug traces in test suites.

  `run_cmd`(*args)

    Run a system command, print output and return results.

  `setUp`()

`meta_package_manager.tests.case.` `skip_destructive`()

  Decorator to skip a test unless destructive mode is allowed.

  Destructive mode is activated by the presence of a `DESTRUCTIVE_TESTS` environment variable set to `True`.

`meta_package_manager.tests.case.` `unless_linux`()

  Decorator to skip a test unless it is run on a Linux system.

`meta_package_manager.tests.case.` `unless_macos`()

  Decorator to skip a test unless it is run on a macOS system.

`meta_package_manager.tests.case.` `unless_windows`()

  Decorator to skip a test unless it is run on a Windows system.

## meta_package_manager.tests.test_bitbar_plugin module

class `meta_package_manager.tests.test_bitbar_plugin.` `TestBitBarPlugin`(methodName='runTest')

  Bases: `meta_package_manager.tests.case.CLITestCase`

  `test_simple_call`()

## meta_package_manager.tests.test_cli module

class `meta_package_manager.tests.test_cli.` `TestCLI`(methodName='runTest')

  Bases: `meta_package_manager.tests.case.CLITestCase`

  `test_bare_call`()
  `test_main_help`()
  `test_verbosity`()
  `test_version`()

class `meta_package_manager.tests.test_cli.` `TestCLIManagers`(methodName='runTest')

  Bases: `meta_package_manager.tests.case.CLITestCase`

  `test_json_debug_output`()
  `test_json_output`()
  `test_main_help`()
  `test_plain_table_rendering`()
  `test_simple_call`()
  `test_simple_table_rendering`()
  `test_sub_manager_scope`()
  `test_verbosity`()

class `meta_package_manager.tests.test_cli.` `TestCLIOutdated`(methodName='runTest')

  Bases: `meta_package_manager.tests.case.CLITestCase`

  `test_cli_format_bitbar`()
  `test_cli_format_fragments`()
  `test_cli_format_plain`()
  `test_json_debug_output`()
  `test_json_output`()
  `test_main_help`()
  `test_plain_table_rendering`()
  `test_simple_call`()
  `test_simple_table_rendering`()
  `test_sub_manager_scope`()
  `test_verbosity`()

class `meta_package_manager.tests.test_cli.` `TestCLISync`(methodName='runTest')

  Bases: `meta_package_manager.tests.case.CLITestCase`

  `test_main_help`()
  `test_simple_call`()
  `test_sub_manager_scope`()
  `test_verbosity`()

class `meta_package_manager.tests.test_cli.` `TestCLIUpgrade`(methodName='runTest')

  Bases: `meta_package_manager.tests.case.CLITestCase`

  `test_full_upgrade`(*args, **kwargs)
  `test_main_help`()
  `test_simple_call`()
  `test_sub_manager_scope`()
  `test_verbosity`()

## meta_package_manager.tests.test_managers module

class `meta_package_manager.tests.test_managers.` `TestManagerDefinitions`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Test the definition of all package managers.

  `test_ascii_id`()

    All package manager IDs should be short ASCII strings.

  `test_cli_args_type`()

    Check that definitions returns CLI args as a list.

  `test_cli_path_type`()

    Check that definitions returns the CLI path as a string.

  `test_cli_type`()

    Check that all methods returning a CLI is a list.

  `test_number`()

    Check all implemented package managers are accounted for.

  `test_platforms_type`()

    Check that definitions returns supported platforms as a frozenset.

  `test_platforms_values`()

    Check that definitions returns platforms with a registered label.

class `meta_package_manager.tests.test_managers.` `TestManagerPlatform`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `test_linux`(*args, **kwargs)
  `test_macos`()
  `test_windows`(*args, **kwargs)

## Module contents